Module: Reflex::Packager

Defined in:
lib/reflex/packager/config.rb,
lib/reflex/packager/cli.rb,
lib/reflex/packager/macos.rb,
lib/reflex/packager/profile.rb,
lib/reflex/packager/platform.rb,
lib/reflex/packager/extension.rb,
lib/reflex/packager.rb

Overview

Tools to package a Reflex application as a distributable bundle. Files under this directory must not require ‘reflex’ because it has side effects such as requiring native extensions.

Defined Under Namespace

Modules: Extension Classes: CLI, Config, Error, MacOS, MacOSConfig, Platform, Profile

Constant Summary collapse

TEMPLATES_DIR =
File.expand_path 'templates', __dir__
PLATFORMS =
{macos: MacOS}